<?php
/**
 * @file
 * Admin settings form and related admin-only functions.
 */


/**
 * Form builder:  The admin settings for API authentication credentials.
 */
function kazoo_admin_form($form, &$form_state) {
  // Check the credentials if this form is being build for the first time.
  $token = variable_get('kazoo_api_hash');
  if (empty($form_state['input']) && !empty($token)) {
    if (kazoo_check_credentials()) {
      drupal_set_message(t('The current credentials are valid.'), 'status', FALSE);
    }
    else {
      drupal_set_message(t('The current credentials are not valid.'), 'error', FALSE);
    }
  }

  $form['url'] = array(
    '#type' => 'textfield',
    '#title' => t('Kazoo API base URL'),
    '#description' => t('This should include the protocol, port and version.  Exclude the trailing slash.  E.g. !example', array('!example' => "<code>http://api.2600hz.com:8000/v1</code>")),
    '#required' => TRUE,
    '#default_value' => kazoo_var('access_point'),
  );

  $hash = (Boolean) kazoo_var('hash');

  $form['credentials'] = array(
    '#type' => 'fieldset',
    '#title' => t('Credentials'),
    '#description' => t('Leave blank to use the existing credentials.'),
    '#collapsible' => $hash,
    '#collapsed' => TRUE,
  );

  $form['credentials']['username'] = array(
    '#type' => 'textfield',
    '#title' => t('User name'),
    '#description' => t('The username of the user Drupal should use to authenticate with the Kazoo API.'),
    '#required' => !$hash,
  );

  $form['credentials']['password'] = array(
    '#type' => 'password',
    '#title' => t('Password'),
    '#required' => !$hash,
  );

  $form['credentials']['account_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Account name'),
    '#default_value' => kazoo_var('account_name'),
  );

  $form['actions']['#type'] = 'actions';
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  $form['#theme'] = 'system_settings_form';

  return $form;
}

/**
 * Form validate:  Validates API authentication credentials.
 *
 * Checks the API authentication credentials and stores a hash of the username
 * and password, as well as the access point URL, authentication token and
 * account ID.
 */
function kazoo_admin_form_validate($form, &$form_state) {
  $values = &$form_state['values'];

  // Get the MD5 hash, but do not store the raw username and password.
  $name = $values['username'];
  $pass = $values['password'];
  $hash = (empty($name) && empty($pass)) ? kazoo_var('hash') : md5("$name:$pass");
  $url = trim($values['url'], '/');

  // Check the credentials if there is at least a hash and a URL.
  if (!empty($values['url']) && !empty($hash)) {
    $query = new kazoo_api_auth($hash, $values['account_name'], $url);
    $query->execute();
    // $query->debug();

    if (!$query->code) {
      form_set_error('url', t('Invalid address in the URL.'));
    }
    else if ($query->error || empty($query->result->auth_token)) {
      form_set_error('username', t('Drupal could not authenticate with the Kazoo API using these credentials.'));
      form_set_error('password');
      form_set_error('account_name');
    }
    else {
      // Set the variables that are to be saved to the database.
      $values['kazoo_api'] = array(
        'access_point' => $url,
        'account_id'   => $query->result->data->account_id,
        'account_name' => $values['account_name'],
        'hash'         => $hash,
        'token'        => $query->result->auth_token,
      );
    }
  }
}

/**
 * Form submit: Saves settings to the variables table in the database.
 */
function kazoo_admin_form_submit($form, &$form_state) {
  foreach ($form_state['values']['kazoo_api'] as $name => $value) {
    variable_set("kazoo_api_$name", $value);
  }

  drupal_set_message('The new credentials were saved.');
}
